@@ -3,8 +3,8 @@
 ;; Copyright (C) 2025 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti
-;; Package-Version: 20250915.112
-;; Package-Revision: 99004e3a2539
+;; Package-Version: 20251103.1432
+;; Package-Revision: c403debb8869
 ;; URL: https://github.com/jamescherti/stripspace.el
 ;; Keywords: convenience
 ;; Package-Requires: ((emacs "24.3"))
@@ -336,8 +336,7 @@ current tab width settings."
 
 ;;;###autoload
 (define-minor-mode stripspace-local-mode
-  "Toggle `stripspace-local-mode'.
-This mode ensures that trailing whitespace is removed before saving a buffer."
+  "Minor mode that removes trailing whitespace before a buffer is saved."
   :global nil
   :lighter " StripSPC"
   :group 'stripspace
